##
##
##  Per-host configuration for evergloam
##
##
{
  inputs,
  pkgs,
  ...
}: {
  imports = [inputs.home-manager.nixosModules.home-manager];

  home-manager = {
    useGlobalPkgs = true;
    useUserPackages = true;
    users.jas = {
      imports = [./home.nix];
    };
  };

  networking.hosts = {
    "10.0.0.191" = ["nexus.local"];
    "10.0.0.27" = ["logs.local"];
    "10.0.0.159" = ["truenas.local"];
    "10.0.0.41" = ["moonshadow.local"];
    "10.0.0.223" = ["soft-serve.local"];
  };

  networking.firewall.allowedTCPPorts = [22];

  services.znapzend = {
    enable = true;
    autoCreation = true;
    zetup."rpool/nixos" = {
      enable = true;
      plan = "1y=>1d";
      recursive = false;
      destinations.remote = {
        host = "root@truenas.local";
        dataset = "nas/evergloam";
      };
    };
  };

  zfs-root = {
    boot = {
      devNodes = "/dev/disk/by-id/";
      bootDevices = ["nvme-SKHynix_HFS512GEJ9X113N_4YC2N026710904U3D"];
      immutable = false;
      availableKernelModules = ["xhci_pci" "thunderbolt" "nvme" "usb_storage" "sd_mod"];
      removableEfi = true;
      kernelParams = [];
      sshUnlock = {
        # read sshUnlock.txt file.
        enable = false;
        authorizedKeys = [];
      };
    };
    networking = {
      # read changeHostName.txt file.
      hostName = "evergloam";
      timeZone = "America/Chicago";
      hostId = "f44d0bef";
    };
  };

  # To add more options to per-host configuration, you can create a
  # custom configuration module, then add it here.
  my-config = {
    template.all.packages.enable = true;
    template.all.zfs.enable = true;
    template.desktop.custom.enable = true;
  };
}
