##
##
##  Per-host configuration for moonshadow
##
##
{
  inputs,
  pkgs,
  ...
}: {
  imports = [inputs.home-manager.nixosModules.home-manager];

  home-manager = {
    useGlobalPkgs = true;
    useUserPackages = true;
    users.jas = {
      imports = [./home.nix];
    };
  };

  networking.hosts = {
    "10.0.0.191" = ["nexus.local"];
    "10.0.0.27" = ["logs.local"];
    "10.0.0.159" = ["truenas.local"];
    "10.0.0.28" = ["evergloam.local"];
    "10.0.0.223" = ["soft-serve.local"];
  };

  networking.firewall.allowedTCPPorts = [22];

  services.znapzend = {
    enable = true;
    autoCreation = true;
    zetup."rpool/nixos" = {
      enable = true;
      plan = "1y=>1d";
      recursive = false;
      destinations.remote = {
        host = "root@truenas.local";
        dataset = "nas/moonshadow";
      };
    };
  };

  systemd.tmpfiles.rules = [
    "L+ /run/gdm/.config/monitors.xml - - - - ${pkgs.writeText "gdm-monitors" ''
      <monitors version="2">
        <configuration>
          <logicalmonitor>
            <x>0</x>
            <y>0</y>
            <scale>2</scale>
            <monitor>
              <monitorspec>
                <connector>DP-2</connector>
                <vendor>GSM</vendor>
                <product>LG Ultra HD</product>
                <serial>0x00003868</serial>
              </monitorspec>
              <mode>
                <width>3840</width>
                <height>2160</height>
                <rate>59.997</rate>
              </mode>
            </monitor>
          </logicalmonitor>
          <logicalmonitor>
            <x>3840</x>
            <y>0</y>
            <scale>2</scale>
            <primary>yes</primary>
            <monitor>
              <monitorspec>
                <connector>DP-0</connector>
                <vendor>GSM</vendor>
                <product>LG Ultra HD</product>
                <serial>0x000722dd</serial>
              </monitorspec>
              <mode>
                <width>3840</width>
                <height>2160</height>
                <rate>59.997</rate>
              </mode>
            </monitor>
          </logicalmonitor>
        </configuration>
      </monitors>
    ''}"
  ];

  zfs-root = {
    boot = {
      devNodes = "/dev/disk/by-id/";
      bootDevices = ["nvme-Samsung_SSD_980_PRO_1TB_S5P2NL0W208026M"];
      immutable = false;
      availableKernelModules = ["nvme" "thunderbolt" "xhci_pci" "ahci" "usbhid" "usb_storage" "sd_mod"];
      removableEfi = true;
      kernelParams = [];
      sshUnlock = {
        # read sshUnlock.txt file.
        enable = false;
        authorizedKeys = [];
      };
    };
    networking = {
      # read changeHostName.txt file.
      hostName = "moonshadow";
      timeZone = "America/Chicago";
      hostId = "d3c87a8b";
    };
  };

  # To add more options to per-host configuration, you can create a
  # custom configuration module, then add it here.
  my-config = {
    template.all.packages.enable = true;
    template.all.zfs.enable = true;
    template.any.nvidia.enable = true;
    template.any.system76.enable = true;
    template.desktop.custom.enable = true;
  };
}
