{
  lib,
  pkgs,
  ...
}:
with lib.hm.gvariant; {
  imports = [./dconf.nix];

  home = {
    username = "jas";
    homeDirectory = "/home/jas";
    stateVersion = "23.05";
  };

  programs.git = {
    enable = true;
    userEmail = "23226432+hyperreal64@users.noreply.github.com";
    userName = "Jeffrey Serio";
    extraConfig = {
      safe.directory = "/etc/nixos";
      core = {
        editor = "vim";
        pager = "diff-so-fancy | less --tabs=4 -RFX";
      };
      init.defaultBranch = "main";
      pull.rebase = true;
    };
  };

  programs.gpg = {
    enable = true;
    settings = {
      default-key = "0x9129BD07C3509CED";
      no-emit-version = true;
      no-comments = true;
      display-charset = "utf-8";
      keyid-format = "0xlong";
      with-fingerprint = true;
      use-agent = true;
    };
  };

  programs.fzf = {
    enable = true;
    defaultCommand = "fd --type f";
  };

  programs.bat = {
    enable = true;
    config = {
      pager = "less -FR";
      theme = "Catppuccin-Mocha";
    };
  };

  manual.json.enable = true;

  xdg.userDirs = {
    enable = true;
    createDirectories = true;
    documents = "\$HOME/Nextcloud/documents";
    download = "\$HOME/downloads";
    pictures = "\$HOME/Nextcloud/pictures";
    publicShare = "\$HOME/public";
    music = "\$HOME/misc/music";
    videos = "\$HOME/misc/videos";
    templates = "\$HOME/misc/templates";
  };

  services.nextcloud-client.enable = true;

  programs.ssh = {
    enable = true;
    matchBlocks = {
      "nexus.local" = {
        hostname = "nexus.local";
        user = "jas";
        identityFile = "/home/jas/.ssh/id_ed25519";
      };
      "hyperreal.coffee" = {
        hostname = "hyperreal.coffee";
        user = "jas";
        identityFile = "/home/jas/.ssh/id_ed25519";
      };
      "nc.hyperreal.coffee" = {
        hostname = "nc.hyperreal.coffee";
        user = "jas";
        identityFile = "/home/jas/.ssh/id_ed25519";
      };
      "soft-serve" = {
        hostname = "soft-serve.local";
        port = 23231;
        identityFile = "/home/jas/.ssh/id_ed25519";
      };
    };
  };

  gtk = {
    enable = true;
    iconTheme = {
      name = "Papirus-Dark";
      package = pkgs.catppuccin-papirus-folders.override {
        flavor = "mocha";
        accent = "red";
      };
    };
    theme = {
      name = "Catppuccin-Mocha-Standard-Red-Dark";
      package = pkgs.catppuccin-gtk.override {
        accents = ["red"];
        size = "standard";
        variant = "mocha";
      };
    };
  };
}
