##
##
## Per-host configuration for nexus
##
##
{
  inputs,
  pkgs,
  ...
}: {
  imports = [inputs.home-manager.nixosModules.home-manager];

  home-manager = {
    useGlobalPkgs = true;
    useUserPackages = true;
    users.jas = {
      imports = [./home.nix];
    };
  };

  networking.firewall.allowedTCPPorts = [22 444 8000 9000 9999 35353 35354];

  networking.hosts = {
    "10.0.0.27" = ["logs.local"];
    "10.0.0.159" = ["truenas.local"];
    "10.0.0.223" = ["soft-serve.local"];
  };

  services.znapzend = {
    enable = true;
    autoCreation = true;
    zetup = {
      "rpool/nixos" = {
        enable = true;
        plan = "1y=>1d";
        recursive = false;
        destinations.remote = {
          host = "root@truenas.local";
          dataset = "nas/nexus";
        };
      };

      "si-pool/lxd/containers/debian-archive" = {
        enable = true;
        plan = "1y=>1d";
        recursive = true;
        destinations.remote = {
          host = "root@truenas.local";
          dataset = "nas/debian-archive";
        };
      };

      "si-pool/lxd/containers/debian-serv" = {
        enable = true;
        plan = "1y=>1d";
        recursive = true;
        destinations.remote = {
          host = "root@truenas.local";
          dataset = "nas/debian-serv";
        };
      };

      "si-pool/lxd/containers/ubuntu-mastodon" = {
        enable = true;
        plan = "1y=>1d";
        recursive = true;
        destinations.remote = {
          host = "root@truenas.local";
          dataset = "nas/ubuntu-mastodon";
        };
      };
    };
  };

  virtualisation.lxc.lxcfs.enable = true;
  virtualisation.lxd.enable = true;
  users.users.jas = {
    extraGroups = ["lxd"];
  };

  zfs-root = {
    boot = {
      devNodes = "/dev/disk/by-id/";
      bootDevices = ["nvme-Samsung_SSD_980_PRO_1TB_S5P2NL0W208007T"];
      immutable = false;
      availableKernelModules = ["nvme" "thunderbolt" "xhci_pci" "ahci" "uas" "usbhid" "usb_storage" "sd_mod"];
      removableEfi = true;
      kernelParams = ["systemd.unified_cgroup_hierarchy=0"];
      sshUnlock = {
        # read sshUnlock.txt file.
        enable = false;
        authorizedKeys = [];
      };
    };
    networking = {
      # read changeHostName.txt file.
      hostName = "nexus";
      timeZone = "America/Chicago";
      hostId = "1eceb95c";
    };
  };

  # To add more options to per-host configuration, you can create a
  # custom configuration module, then add it here.
  my-config = {
    template.all.packages.enable = true;
    template.all.zfs.enable = true;
    template.any.system76.enable = true;
    template.server.services.enable = true;
  };
}
